@@ -9,15 +9,17 @@ For detailed document, please see:
 
 # flake8: noqa
 
-__version__ = '7.1.0'
+__version__ = '7.1.4'
 
 from .auth import Auth, QiniuMacAuth
 
 from .config import set_default
 from .zone import Zone
 
-from .services.storage.bucket import BucketManager, build_batch_copy, build_batch_rename, build_batch_move, build_batch_stat, build_batch_delete
+from .services.storage.bucket import BucketManager, build_batch_copy, build_batch_rename, build_batch_move, \
+    build_batch_stat, build_batch_delete
 from .services.storage.uploader import put_data, put_file, put_stream
+from .services.cdn.manager import CdnManager, create_timestamp_anti_leech_url
 from .services.processing.pfop import PersistentFop
 from .services.processing.cmd import build_op, pipe_cmd, op_save
 from .services.compute.app import AccountClient
